execute_in_process

Function execute_in_process 

pub async fn execute_in_process(
    schema: &KoanSchema,
    query: &str,
    variables: Option<Value>,
    user_id: i64,
    role: Role,
) -> Value
Execute a GraphQL query in-process (no HTTP round-trip).

There is no credential to check, so the caller states who the query runs as and at what role — see mcp::mcp_role.