execute_in_process

Function execute_in_process 

pub async fn execute_in_process(
    schema: &KoanSchema,
    query: &str,
    variables: Option<Value>,
    role: Role,
) -> Value
Execute a GraphQL query in-process (no HTTP round-trip).

There is no credential to check, so the caller states the role it wants the query executed at — see mcp::mcp_role.